@@ -130,19 +130,13 @@ pub fn solve(
         (2017, 2, _) => to_stringer_input(year2017::day02::solve, &mut input),
         (2017, 3, _) => to_stringer_input(year2017::day03::solve, &mut input),
         (2017, 4, _) => to_stringer_input(year2017::day04::solve, &mut input),
-        (2017, 5, 1) => to_stringer(year2017::day05::part1, input_string),
-        (2017, 5, 2) => to_stringer(year2017::day05::part2, input_string),
-        (2017, 6, 1) => to_stringer(year2017::day06::part1, input_string),
-        (2017, 6, 2) => to_stringer(year2017::day06::part2, input_string),
-        (2017, 7, 1) => to_stringer(year2017::day07::part1, input_string),
-        (2017, 7, 2) => to_stringer(year2017::day07::part2, input_string),
+        (2017, 5, _) => to_stringer_input(year2017::day05::solve, &mut input),
+        (2017, 6, _) => to_stringer_input(year2017::day06::solve, &mut input),
+        (2017, 7, _) => to_stringer_input(year2017::day07::solve, &mut input),
         (2017, 8, _) => to_stringer_input(year2017::day08::solve, &mut input),
-        (2017, 9, 1) => to_stringer(year2017::day09::part1, input_string),
-        (2017, 9, 2) => to_stringer(year2017::day09::part2, input_string),
-        (2017, 10, 1) => to_stringer(year2017::day10::part1, input_string),
-        (2017, 10, 2) => to_stringer(year2017::day10::part2, input_string),
-        (2017, 11, 1) => to_stringer(year2017::day11::part1, input_string),
-        (2017, 11, 2) => to_stringer(year2017::day11::part2, input_string),
+        (2017, 9, _) => to_stringer_input(year2017::day09::solve, &mut input),
+        (2017, 10, _) => to_stringer_input(year2017::day10::solve, &mut input),
+        (2017, 11, _) => to_stringer_input(year2017::day11::solve, &mut input),
         (2017, 12, _) => to_stringer_input(year2017::day12::solve, &mut input),
         (2017, 13, _) => to_stringer_input(year2017::day13::solve, &mut input),
         (2017, 14, _) => to_stringer_input(year2017::day14::solve, &mut input),
@@ -157,8 +151,7 @@ pub fn solve(
         (2017, 23, _) => to_stringer_input(year2017::day23::solve, &mut input),
         (2017, 24, _) => to_stringer_input(year2017::day24::solve, &mut input),
         (2017, 25, _) => to_stringer_input(year2017::day25::solve, &mut input),
-        (2018, 1, 1) => to_stringer(year2018::day01::part1, input_string),
-        (2018, 1, 2) => to_stringer(year2018::day01::part2, input_string),
+        (2018, 1, _) => to_stringer_input(year2018::day01::solve, &mut input),
         (2018, 2, 1) => to_stringer(year2018::day02::part1, input_string),
         (2018, 2, 2) => to_stringer(year2018::day02::part2, input_string),
         (2018, 3, 1) => to_stringer(year2018::day03::part1, input_string),
